@@ -236,6 +236,6 @@ class SciNoteClient(object):
                 "attributes": {"name": name, "parent_folder_id": parent_folder_id},
             }
         }
-        r = self.post(url, json=data)
+        r = self.post(url, data)
 
         return r.json()
